import locale

locale.setlocale(locale.LC_ALL, "pt_BR.UTF-8")


def moeda(valor, symbol=False):
    return locale.currency(valor, symbol=symbol, grouping=True)


def numero(valor, casas=0):
    if isinstance(valor, (int, float)):
        formato = f"%.{casas}f"
        return locale.format_string(formato, valor, grouping=True)
    else:
        print("[error] O valor fornecido não é um número.")
        return valor


def data_extenso(data):
    if hasattr(data, "strftime"):
        return data.strftime("%a %d de %B %Y")
    else:
        return " - "


def data_br(data):
    if hasattr(data, "strftime"):
        return data.strftime("%d/%m/%Y")
    else:
        return " - "


def ipre(df):
    # Preparar os dados para a tabela
    tabela = []
    for coluna in df.columns:
        valor_simples = df[coluna].iloc[0]  # Obtém o primeiro valor da coluna
        tipo_dado = df[coluna].dtype  # Obtém o tipo de dado da coluna
        tabela.append([coluna, valor_simples, tipo_dado])

    # Calcular o comprimento máximo de cada coluna para formatação
    col_widths = [
        max(len(str(item)) for item in col)
        for col in zip(*tabela, ["Nome da Coluna", "Valor Simples", "Tipo de Dados"])
    ]

    # Função para formatar uma linha
    def format_row(row):
        return (
            "| "
            + " | ".join(
                f"{str(item).ljust(width)}" for item, width in zip(row, col_widths)
            )
            + " |"
        )

    # Cabeçalhos da tabela
    headers = ["Coluna", "Valor", "Tipo de Dados"]

    # Linha separadora
    separator = "+-" + "-+-".join("-" * width for width in col_widths) + "-+"

    # Imprimir a tabela
    print(separator)
    print(format_row(headers))
    print(separator)
    for row in tabela:
        print(format_row(row))
    print(separator)


def get_tipo_de_colunas():
    return {
        "porcetagem": {
            "baseDataType": "number",
            "extendsDataType": "number",
            "valueFormatter": {
                "function": '( params.value  || 0).toLocaleString("pt-BR", { minimumFractionDigits: 2, maximumFractionDigits: 2 })+ "%"',
            },
        },
        "moeda": {
            "baseDataType": "number",
            "extendsDataType": "number",
            "valueFormatter": {
                "function": '(params.value || 0).toLocaleString("pt-BR", { minimumFractionDigits: 2, maximumFractionDigits: 2 })',
            },
        },
        "numero": {
            "baseDataType": "number",
            "extendsDataType": "number",
            "valueFormatter": {
                "function": '(params.value || 0).toLocaleString("pt-BR", { minimumFractionDigits: 0, maximumFractionDigits: 0 })',
            },
        },
        "data": {
            "baseDataType": "date",
            "extendsDataType": "date",
            "filterValueGetter": {
                "function": f"""( 
                            d3.timeParse('%Y-%m-%d')(params.value) !== null ? 
                            d3.timeFormat('%d/%m/%Y')(d3.timeParse('%Y-%m-%d')(params.value )) 
                            :  params.value
                            
                        ) """
            },
            "valueFormatter": {
                "function": f"""( 
                            d3.timeParse('%Y-%m-%d')(params.value) !== null ? 
                            d3.timeFormat('%d/%m/%Y')(d3.timeParse('%Y-%m-%d')(params.value )) 
                            :  params.value
                            
                        ) """
            },
        },
        "datatime": {
            "baseDataType": "date",
            "extendsDataType": "date",
            "valueFormatter": {
                "function": f"""( 
                            d3.timeParse('%Y-%m-%dT%H:%M:%S')(params.value) !== null ? 
                            d3.timeFormat('%d/%m/%Y')(d3.timeParse('%Y-%m-%dT%H:%M:%S')(params.value )) 
                            :  params.value
                            
                        ) """
            },
        },
    }


def get_pt_br():
    return {
        "selectAll": "Selecionar tudo",
        "selectAllSearchResults": "Selecionar todos os resultados da busca",
        "addCurrentSelectionToFilter": "Adicionar seleção atual ao filtro",
        "searchOoo": "Buscar...",
        "blanks": "(Em branco)",
        "noMatches": "Sem correspondências",
        "filterOoo": "Filtrar...",
        "equals": "Igual",
        "notEqual": "Diferente",
        "blank": "Em branco",
        "notBlank": "Não em branco",
        "empty": "Escolha um",
        "lessThan": "Menor que",
        "greaterThan": "Maior que",
        "lessThanOrEqual": "Menor ou igual a",
        "greaterThanOrEqual": "Maior ou igual a",
        "inRange": "Entre",
        "inRangeStart": "De",
        "inRangeEnd": "Até",
        "contains": "Contém",
        "notContains": "Não contém",
        "startsWith": "Começa com",
        "endsWith": "Termina com",
        "before": "Antes de",
        "after": "Depois de",
        "andCondition": "E",
        "orCondition": "OU",
        "applyFilter": "Aplicar",
        "resetFilter": "Redefinir",
        "clear": "Limpar",
        "clearFilter": "Limpar",
        "cancelFilter": "Cancelar",
        "textFilter": "Filtro de texto",
        "numberFilter": "Filtro numérico",
        "dateFilter": "Filtro de data",
        "setFilter": "Configurar filtro",
        "groupFilterSelect": "Selecionar campo:",
        "advancedFilterContains": "contém",
        "advancedFilterNotContains": "não contém",
        "advancedFilterTextEquals": "é igual",
        "advancedFilterTextNotEqual": "não é igual",
        "advancedFilterStartsWith": "começa com",
        "advancedFilterEndsWith": "termina com",
        "advancedFilterBlank": "está em branco",
        "advancedFilterNotBlank": "não está em branco",
        "advancedFilterEquals": "=",
        "advancedFilterNotEqual": "!=",
        "advancedFilterGreaterThan": ">",
        "advancedFilterGreaterThanOrEqual": ">=",
        "advancedFilterLessThan": "<",
        "advancedFilterLessThanOrEqual": "<=",
        "columns": "Colunas",
        "filters": "Filtros",
        "pivotMode": "Modo Pivot",
        "groups": "Grupos de Linhas",
        "rowGroupColumnsEmptyMessage": "Arraste aqui para definir grupos de linhas",
        "values": "Valores",
        "valueColumnsEmptyMessage": "Arraste aqui para agregar",
        "pivots": "Rótulos de Coluna",
        "pivotColumnsEmptyMessage": "Arraste aqui para definir rótulos de coluna",
        "group": "Grupo",
        "rowDragRow": "linha",
        "rowDragRows": "linhas",
        "loadingOoo": "Carregando...",
        "loadingError": "ERRO",
        "noRowsToShow": "Nenhuma linha para mostrar",
        "enabled": "Habilitado",
        "pinColumn": "Fixar coluna",
        "pinLeft": "Fixar à esquerda",
        "pinRight": "Fixar à direita",
        "noPin": "Não fixar",
        "valueAggregation": "Agregação de Valor",
        "noAggregation": "Nenhum",
        "autosizeThiscolumn": "Redimensionar esta coluna",
        "autosizeAllColumns": "Redimensionar todas as colunas",
        "groupBy": "Agrupar por",
        "ungroupBy": "Desagrupar por",
        "ungroupAll": "Desagrupar tudo",
        "addToValues": "Adicionar ${variable} aos valores",
        "removeFromValues": "Remover ${variable} dos valores",
        "addToLabels": "Adicionar ${variable} aos rótulos",
        "removeFromLabels": "Remover ${variable} dos rótulos",
        "resetColumns": "Redefinir colunas",
        "expandAll": "Expandir todos os grupos de linhas",
        "collapseAll": "Fechar todos os grupos de linhas",
        "copy": "Copiar",
        "ctrlC": "Ctrl+C",
        "ctrlX": "Ctrl+X",
        "copyWithHeaders": "Copiar com cabeçalhos",
        "copyWithGroupHeaders": "Copiar com cabeçalhos de grupo",
        "cut": "Cortar",
        "paste": "Colar",
        "ctrlV": "Ctrl+V",
        "export": "Exportar",
        "csvExport": "Exportar para CSV",
        "excelExport": "Exportar para Excel",
        "columnFilter": "Filtro de Coluna",
        "columnChooser": "Escolher Colunas",
        "sortAscending": "Ordenar Ascendente",
        "sortDescending": "Ordenar Descendente",
        "sortUnSort": "Limpar Ordenação",
        "sum": "Soma",
        "first": "Primeiro",
        "last": "Último",
        "min": "Mínimo",
        "max": "Máximo",
        "none": "Nenhum",
        "count": "Contagem",
        "avg": "Média",
        "filteredRows": "Filtrado",
        "selectedRows": "Selecionado",
        "totalRows": "Total de Linhas",
        "totalAndFilteredRows": "Linhas",
        "more": "Mais",
        "to": "para",
        "of": "de",
        "page": "Página",
        "pageLastRowUnknown": "?",
        "nextPage": "Próxima Página",
        "lastPage": "Última Página",
        "selectAll": "(Selecionar tudo)",
        "selectAllSearchResults": "(Selecionar todos os resultados da pesquisa)",
        "searchOoo": "Pesquisando...",
        "blanks": "(Em branco)",
        "noMatches": "Nenhum resultado encontrado",
        "filterOoo": "Filtrando...",
        "equals": "Igual a",
        "notEqual": "Diferente de",
        "empty": "Vazio",
        "lessThan": "Menor que",
        "greaterThan": "Maior que",
        "lessThanOrEqual": "Menor ou igual a",
        "greaterThanOrEqual": "Maior ou igual a",
        "inRange": "Entre",
        "inRangeStart": "De",
        "inRangeEnd": "Até",
        "contains": "Contém",
        "notContains": "Não contém",
        "startsWith": "Começa com",
        "endsWith": "Termina com",
        "dateFormatOoo": "dd/mm/yyyy",
        "andCondition": "E",
        "orCondition": "OU",
        "applyFilter": "Aplicar filtro",
        "resetFilter": "Redefinir filtro",
        "clearFilter": "Limpar filtro",
        "cancelFilter": "Cancelar filtro",
        "textFilter": "Filtro de texto",
        "numberFilter": "Filtro numérico",
        "dateFilter": "Filtro de data",
        "setFilter": "Definir filtro",
        "columns": "Colunas",
        "filters": "Filtros",
        "pivotMode": "Modo de agrupamento",
        "groups": "Grupos",
        "rowGroupColumnsEmptyMessage": "Arraste uma coluna para o grupo",
        "values": "Valores",
        "valueColumnsEmptyMessage": "Arraste uma coluna para o valor",
        "pivots": "Agrupamentos",
        "pivotColumnsEmptyMessage": "Arraste uma coluna para o agrupamento",
        "group": "Grupo",
        "loadingOoo": "Carregando...",
        "noRowsToShow": "Nenhum registro para mostrar",
        "enabled": "Habilitado",
        "pinColumn": "Fixar coluna",
        "pinLeft": "Fixar à esquerda",
        "pinRight": "Fixar à direita",
        "noPin": "Não fixar",
        "valueAggregation": "Agregação de valores",
        "autosizeThiscolumn": "Redimensionar esta coluna",
        "autosizeAllColumns": "Redimensionar todas as colunas",
        "groupBy": "Agrupar por",
        "ungroupBy": "Desagrupar por",
        "resetColumns": "Redefinir colunas",
        "expandAll": "Expandir todos",
        "collapseAll": "Recolher todos",
        "copy": "Copiar",
        "ctrlC": "Ctrl+C",
        "copyWithHeaders": "Copiar com cabeçalhos",
        "paste": "Colar",
        "ctrlV": "Ctrl+V",
        "export": "Exportar",
        "csvExport": "Exportar para CSV",
        "excelExport": "Exportar para Excel",
        "sum": "Soma",
        "min": "Mínimo",
        "max": "Máximo",
        "none": "Nenhum",
        "count": "Contagem",
        "avg": "Média",
        "filteredRows": "Linhas filtradas",
        "selectedRows": "Linhas selecionadas",
        "totalRows": "Total de linhas",
        "totalAndFilteredRows": "Total e linhas filtradas",
        "more": "Mais",
        "to": "para",
        "of": "de",
        "page": "Página",
        "nextPage": "Próxima página",
        "lastPage": "Última página",
        "firstPage": "Primeira página",
        "previousPage": "Página anterior",
        "pivotColumnGroupTotals": "Total de grupo de colunas",
        "pivotChartAndPivotMode": "Grafíco Pivô & Modo Pivô",
        "pivotChart": "Gráfico Pivô",
        "chartRange": "Alcance do gráfico",
        "columnChart": "Coluna",
        "groupedColumn": "Agrupada",
        "stackedColumn": "Empilhada",
        "normalizedColumn": "100% empilhada",
        "barChart": "Barras",
        "groupedBar": "Agrupada",
        "stackedBar": "Empilhada",
        "normalizedBar": "100% empilhada",
        "pieChart": "Pizza",
        "pie": "Pizza",
        "doughnut": "Rosquinha",
        "lineChart": "Linha",
        "xyChart": "X Y (Dispersão)",
        "scatter": "Dispersão",
        "bubble": "Bolhas",
        "areaChart": "Área",
        "area": "Área",
        "stackedArea": "Empilhada",
        "normalizedArea": "100% empilhada",
        "histogramChart": "Histograma",
        "pivotChartTitle": "Gráfico Pivô",
        "rangeChartTitle": "Alcance do gráfico",
        "settings": "Configurações",
        "data": "Dados",
        "format": "Formato",
        "categories": "Categorias",
        "defaultCategory": "(padrão)",
        "series": "Séries",
        "xyValues": "Valores X Y",
        "paired": "Par",
        "axis": "Eixo",
        "navigator": "Navegador",
        "color": "Cor",
        "thickness": "Espessura",
        "xType": "Tipo X",
        "automatic": "Automático",
        "category": "Categoria",
        "number": "Número",
        "time": "Tempo",
        "xRotation": "Rotação X",
        "yRotation": "Rotação Y",
        "ticks": "Ticks",
        "width": "Largura",
        "height": "Altura",
        "length": "Comprimento",
        "padding": "Preenchimento",
        "spacing": "Espaçamento",
        "chart": "Gráfico",
        "title": "Título",
        "titlePlaceholder": "Título aqui",
        "background": "Fundo",
        "font": "Fonte",
        "top": "Topo",
        "right": "Direita",
        "bottom": "Fundo",
        "left": "Esquerda",
        "labels": "Rótulos",
        "size": "Tamanho",
        "minSize": "Tamanho mínimo",
        "maxSize": "Tamanho máximo",
        "legend": "Legenda",
        "position": "Posição",
        "markerSize": "Tamanho do marcador",
        "markerStroke": "Marcador de traço",
        "markerPadding": "Marcador de preenchimento",
        "itemSpacing": "Espaçamento do item",
        "itemPaddingX": "Preenchimento X do item",
        "itemPaddingY": "Preenchimento Y do item",
        "layoutHorizontalSpacing": "Espaçamento horizontal do layout",
        "layoutVerticalSpacing": "Espaçamento vertical do layout",
        "strokeWidth": "Espessura do traço",
        "offset": "Offset",
        "offsets": "Offsets",
        "tooltips": "Dicas",
        "callout": "Callout",
        "markers": "Marcadores",
        "shadow": "Sombra",
        "blur": "Desfocar",
        "xOffset": "Offset X",
        "yOffset": "Offset Y",
        "lineWidth": "Largura da linha",
        "normal": "Normal",
        "bold": "Negrito",
        "italic": "Itálico",
        "boldItalic": "Negrito itálico",
        "predefined": "Predefinido",
        "fillOpacity": "Opacidade de preenchimento",
        "strokeOpacity": "Opacidade do traço",
        "histogramBinCount": "Contagem de binário do histograma",
        "columnGroup": "Agrupar coluna",
        "barGroup": "Agrupar barra",
        "pieGroup": "Agrupar pizza",
        "lineGroup": "Agrupar linha",
        "scatterGroup": "Agrupar dispersão",
        "areaGroup": "Agrupar área",
        "histogramGroup": "Agrupar histograma",
        "groupedColumnTooltip": "Agrupar por coluna",
        "stackedColumnTooltip": "Empilhada por coluna",
        "normalizedColumnTooltip": "100% empilhada por coluna",
        "groupedBarTooltip": "Agrupar por barra",
        "stackedBarTooltip": "Empilhada por barra",
        "normalizedBarTooltip": "100% empilhada por barra",
        "pieTooltip": "Pizza",
        "doughnutTooltip": "Rosquinha",
        "lineTooltip": "Linha",
        "groupedAreaTooltip": "Agrupar por área",
        "stackedAreaTooltip": "Empilhada por área",
        "normalizedAreaTooltip": "100% empilhada por área",
        "scatterTooltip": "Dispersão",
        "bubbleTooltip": "Bolha",
        "histogramTooltip": "Histograma",
        "noDataToChart": "Não há dados para gráfico",
        "pivotChartRequiresPivotMode": "Gráfico Pivô requer modo pivô",
        "chartSettingsToolbarTooltip": "Configurações do gráfico",
        "chartLinkToolbarTooltip": "Link do gráfico",
        "chartUnlinkToolbarTooltip": "Desvincular gráfico",
        "chartDownloadToolbarTooltip": "Download do gráfico",
        "sum": "Soma",
        "min": "Mínimo",
        "max": "Máximo",
        "none": "Nenhum",
        "count": "Contagem",
        "avg": "Média",
        "filteredRows": "Linhas filtradas",
        "selectedRows": "Linhas selecionadas",
        "totalRows": "Total de linhas",
        "totalAndFilteredRows": "Total e linhas filtradas",
        "more": "Mais",
        "to": "para",
        "of": "de",
        "page": "Página",
        "nextPage": "Próxima página",
        "lastPage": "Última página",
        "firstPage": "Primeira página",
        "previousPage": "Página anterior",
        "pivotColumnGroupTotals": "Total de grupo de colunas",
        "pivotChartAndPivotMode": "Gráficos e Modo Pivô",
        "pivotChart": "Gráfico Pivô",
        "chartRange": "Alcance do gráfico",
        "columnChart": "Gráfico de Colunas",
        "groupedColumn": "Coluna Agrupada",
        "stackedColumn": "Coluna Empilhada",
        "normalizedColumn": "Coluna Normalizada",
        "barChart": "Gráfico de Barras",
        "groupedBar": "Barra Agrupada",
        "stackedBar": "Barra Empilhada",
        "normalizedBar": "Barra Normalizada",
        "pieChart": "Gráfico de Pizza",
        "pie": "Pizza",
        "doughnut": "Rosquinha",
        "line": "Linha",
        "xyChart": "Gráfico XY (Dispersão)",
        "scatter": "Dispersão",
        "bubble": "Bubble",
        "areaChart": "Gráfico de Área",
        "area": "Área",
        "stackedArea": "Área Empilhada",
        "normalizedArea": "Área Normalizada",
        "histogramChart": "Gráfico de Histograma",
        "pivotChartTitle": "Título do Gráfico Pivô",
        "rangeChartTitle": "Título do Gráfico de Alcance",
        "settings": "Configurações",
        "data": "Dados",
        "format": "Formato",
        "categories": "Categorias",
        "defaultCategory": "(Padrão)",
        "series": "Séries",
        "xyValues": "Valores XY",
        "paired": "Par",
        "axis": "Eixo",
        "navigator": "Navegador",
        "color": "Cor",
        "thickness": "Espessura",
        "xType": "Tipo de X",
        "automatic": "Automático",
        "category": "Categoria",
        "number": "Número",
        "time": "Tempo",
        "xRotation": "Rotação de X",
        "yRotation": "Rotação de Y",
        "ticks": "Ticks",
        "width": "Largura",
        "height": "Altura",
        "length": "Comprimento",
        "padding": "Preenchimento",
        "spacing": "Espaçamento",
        "chart": "Gráfico",
        "title": "Título",
        "titlePlaceholder": "Título Aqui",
        "background": "Fundo",
        "font": "Fonte",
        "top": "Topo",
        "right": "Direita",
        "bottom": "Fundo",
        "left": "Esquerda",
        "labels": "Rótulos",
        "size": "Tamanho",
        "minSize": "Tamanho Mínimo",
        "maxSize": "Tamanho Máximo",
        "legend": "Legenda",
        "position": "Posição",
        "markerSize": "Tamanho do Marcador",
        "markerStroke": "Marcador de Traço",
        "markerPadding": "Preenchimento do Marcador",
        "itemSpacing": "Espaçamento do Item",
        "itemPaddingX": "Preenchimento X do Item",
        "itemPaddingY": "Preenchimento Y do Item",
        "layoutHorizontalSpacing": "Espaçamento Horizontal do Layout",
        "layoutVerticalSpacing": "Espaçamento Vertical do Layout",
        "strokeWidth": "Largura do Traço",
        "offset": "Offset",
        "offsets": "Offsets",
        "tooltips": "Dicas",
        "callout": "Callout",
        "markers": "Marcadores",
        "shadow": "Sombra",
        "blur": "Blur",
        "xOffset": "Offset de X",
        "yOffset": "Offset de Y",
        "lineWidth": "Largura da Linha",
        "normal": "Normal",
        "bold": "Negrito",
        "italic": "Itálico",
        "boldItalic": "Negrito e Itálico",
        "predefined": "Predefinido",
        "fillOpacity": "Opacidade de Preenchimento",
        "strokeOpacity": "Opacidade do Traço",
        "histogramBinCount": "Contagem do Bin do Histograma",
        "columnGroup": "Agrupar Coluna",
        "barGroup": "Agrupar Barra",
        "pieGroup": "Agrupar Pizza",
        "lineGroup": "Agrupar Linha",
        "scatterGroup": "Agrupar Dispersão",
        "areaGroup": "Agrupar Área",
        "histogramGroup": "Agrupar Histograma",
        "groupedColumnTooltip": "Agrupar por Coluna",
        "stackedColumnTooltip": "Empilhada por Coluna",
        "normalizedColumnTooltip": "100% Empilhada por Coluna",
        "groupedBarTooltip": "Agrupar por Barra",
        "stackedBarTooltip": "Empilhada por Barra",
        "normalizedBarTooltip": "100% Empilhada por Barra",
        "pieTooltip": "Pizza",
        "doughnutTooltip": "Rosquinha",
        "lineTooltip": "Linha",
        "groupedAreaTooltip": "Agrupar por Área",
        "stackedAreaTooltip": "Empilhada por Área",
        "normalizedAreaTooltip": "100% Empilhada por Área",
        "scatterTooltip": "Dispersão",
        "bubbleTooltip": "Bubble",
        "histogramTooltip": "Histograma",
        "noDataToChart": "Não há dados para Gráfico",
        "pivotChartRequiresPivotMode": "Gráfico Pivô requer Modo Pivô",
        "chartSettingsToolbarTooltip": "Configurações do Gráfico",
        "chartLinkToolbarTooltip": "Link do Gráfico",
        "chartUnlinkToolbarTooltip": "Desvincular Gráfico",
        "chartDownloadToolbarTooltip": "Download do Gráfico",
        "ariaHidden": "Escondido",
        "ariaVisible": "Visível",
        "ariaChecked": "Verificado",
        "ariaUnchecked": "Não Verificado",
        "ariaIndeterminate": "Indeterminado",
        "ariaDefaultListName": "Lista",
        "ariaColumnSelectAll": "Selecionar Todas as Colunas",
        "ariaInputEditor": "Editor de Entrada",
        "ariaDateFilterInput": "Entrada de Filtro de Data",
        "ariaFilterList": "Filtrar Lista",
        "ariaFilterInput": "Entrada de Filtro",
        "ariaFilterColumnsInput": "Entrada de Filtro de Colunas",
        "ariaFilterValue": "Filtrar Valor",
        "ariaFilterFromValue": "Filtrar pelo Valor de",
        "ariaFilterToValue": "Filtrar pelo Valor para",
        "ariaFilteringOperator": "Operador de Filtragem",
        "ariaColumn": "Coluna",
        "ariaColumnList": "Lista de Colunas",
        "ariaColumnGroup": "Grupo de Colunas",
        "ariaRowSelect": "Pressione ESPAÇO para Selecionar esta Linha",
        "ariaRowDeselect": "Pressione ESPAÇO para Deselecionar esta Linha",
        "ariaRowToggleSelection": "Pressione ESPAÇO para Alternar a Seleção desta Linha",
        "ariaRowSelectAll": "Pressione ESPAÇO para Alternar a Seleção de Todas as Linhas",
        "ariaToggleVisibility": "Pressione ESPAÇO para Alternar a Visibilidade",
        "ariaSearch": "Pesquisar",
        "ariaSearchFilterValues": "Pesquisar Valores de Filtro",
    }
